@@ -18,7 +18,7 @@ from chat_exporter.build_reaction import BuildReaction
 from chat_exporter.build_html import fill_out, start_message, bot_tag, message_reference, message_reference_unknown, \
     message_content, message_body, end_message, total, PARSE_MODE_NONE, PARSE_MODE_MARKDOWN, PARSE_MODE_REFERENCE
 
-from parse_mention import pass_bot
+from chat_exporter.parse_mention import pass_bot
 
 
 bot = None
